# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ConversionOrAdjustmentLagBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConversionOrAdjustmentLagBucket(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket]]: ...
        UNSPECIFIED = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 0)
        UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 1)
        CONVERSION_LESS_THAN_ONE_DAY = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 2)
        CONVERSION_ONE_TO_TWO_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 3)
        CONVERSION_TWO_TO_THREE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 4)
        CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 5)
        CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 6)
        CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 7)
        CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 8)
        CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 9)
        CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 10)
        CONVERSION_NINE_TO_TEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 11)
        CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 12)
        CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 13)
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 14)
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 15)
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 16)
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 17)
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 18)
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 19)
        CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 20)
        ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 21)
        ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 22)
        ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 23)
        ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 24)
        ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 25)
        ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 26)
        ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 27)
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 28)
        ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 29)
        ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 30)
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 31)
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 32)
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 33)
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 34)
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 35)
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 36)
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 37)
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 38)
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 39)
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 40)
        CONVERSION_UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 41)
        ADJUSTMENT_UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 42)
    UNSPECIFIED = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 0)
    UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 1)
    CONVERSION_LESS_THAN_ONE_DAY = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 2)
    CONVERSION_ONE_TO_TWO_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 3)
    CONVERSION_TWO_TO_THREE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 4)
    CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 5)
    CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 6)
    CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 7)
    CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 8)
    CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 9)
    CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 10)
    CONVERSION_NINE_TO_TEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 11)
    CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 12)
    CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 13)
    CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 14)
    CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 15)
    CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 16)
    CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 17)
    CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 18)
    CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 19)
    CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 20)
    ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 21)
    ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 22)
    ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 23)
    ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 24)
    ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 25)
    ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 26)
    ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 27)
    ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 28)
    ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 29)
    ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 30)
    ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 31)
    ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 32)
    ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 33)
    ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 34)
    ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 35)
    ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 36)
    ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 37)
    ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 38)
    ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 39)
    ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 40)
    CONVERSION_UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 41)
    ADJUSTMENT_UNKNOWN = typing___cast(ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket, 42)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionOrAdjustmentLagBucketEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.interaction_event_type_pb2 import (
    InteractionEventTypeEnum as google___ads___googleads___v1___enums___interaction_event_type_pb2___InteractionEventTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.quality_score_bucket_pb2 import (
    QualityScoreBucketEnum as google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Metrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    historical_creative_quality_score = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket
    historical_landing_page_quality_score = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket
    historical_search_predicted_ctr = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket
    interaction_event_types = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v1___enums___interaction_event_type_pb2___InteractionEventTypeEnum.InteractionEventType]

    @property
    def absolute_top_impression_percentage(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def active_view_cpm(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def active_view_ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def active_view_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def active_view_measurability(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def active_view_measurable_cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def active_view_measurable_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def active_view_viewability(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_interactions_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_value_per_cost(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_click_to_call(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_directions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_interactions_value_per_interaction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_menu(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_order(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_other_engagement(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_store_visit(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def all_conversions_from_store_website(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cost(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cpc(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cpe(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cpm(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_cpv(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_frequency(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_page_views(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_position(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def average_time_on_site(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def benchmark_average_max_cpc(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def benchmark_ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def bounce_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def combined_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def combined_clicks_per_query(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def combined_queries(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def content_budget_lost_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def content_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversion_last_received_request_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_last_conversion_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def content_rank_lost_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversions_from_interactions_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversions_value_per_cost(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversions_from_interactions_value_per_interaction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_per_all_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cost_per_conversion(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cost_per_current_model_attributed_conversion(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cross_device_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def current_model_attributed_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def current_model_attributed_conversions_from_interactions_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def current_model_attributed_conversions_from_interactions_value_per_interaction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def current_model_attributed_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def current_model_attributed_conversions_value_per_cost(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def engagement_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def engagements(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def hotel_average_lead_value_micros(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def historical_quality_score(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def gmail_forwards(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def gmail_saves(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def gmail_secondary_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impression_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions_from_store_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def interaction_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def interactions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def invalid_click_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def invalid_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def mobile_friendly_clicks_percentage(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def organic_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def organic_clicks_per_query(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def organic_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def organic_impressions_per_query(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def organic_queries(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def percent_new_visitors(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def phone_calls(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def phone_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def phone_through_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def relative_ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_absolute_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_budget_lost_absolute_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_budget_lost_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_budget_lost_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_click_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_exact_match_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_rank_lost_absolute_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_rank_lost_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_rank_lost_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def search_top_impression_share(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def speed_score(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_impression_percentage(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def valid_accelerated_mobile_pages_clicks_percentage(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def value_per_all_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def value_per_conversion(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def value_per_current_model_attributed_conversion(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_quartile_100_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_quartile_25_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_quartile_50_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_quartile_75_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_view_rate(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def video_views(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def view_through_conversions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        absolute_top_impression_percentage : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        active_view_cpm : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        active_view_ctr : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        active_view_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        active_view_measurability : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        active_view_measurable_cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        active_view_measurable_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        active_view_viewability : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_interactions_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_value_per_cost : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_click_to_call : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_directions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_interactions_value_per_interaction : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_menu : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_order : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_other_engagement : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_store_visit : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        all_conversions_from_store_website : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cost : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpc : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpe : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpm : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpv : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_frequency : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_page_views : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_position : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_time_on_site : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        benchmark_average_max_cpc : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        benchmark_ctr : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        bounce_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        combined_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        combined_clicks_per_query : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        combined_queries : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        content_budget_lost_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        content_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversion_last_received_request_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_last_conversion_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        content_rank_lost_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversions_from_interactions_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversions_value_per_cost : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversions_from_interactions_value_per_interaction : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_per_all_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cost_per_conversion : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cost_per_current_model_attributed_conversion : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cross_device_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        ctr : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        current_model_attributed_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        current_model_attributed_conversions_from_interactions_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        current_model_attributed_conversions_from_interactions_value_per_interaction : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        current_model_attributed_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        current_model_attributed_conversions_value_per_cost : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        engagement_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        engagements : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        hotel_average_lead_value_micros : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        historical_creative_quality_score : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
        historical_landing_page_quality_score : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
        historical_quality_score : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        historical_search_predicted_ctr : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
        gmail_forwards : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        gmail_saves : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        gmail_secondary_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impression_reach : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions_from_store_reach : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        interaction_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        interactions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        interaction_event_types : typing___Optional[typing___Iterable[google___ads___googleads___v1___enums___interaction_event_type_pb2___InteractionEventTypeEnum.InteractionEventType]] = None,
        invalid_click_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        invalid_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        mobile_friendly_clicks_percentage : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        organic_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        organic_clicks_per_query : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        organic_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        organic_impressions_per_query : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        organic_queries : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        percent_new_visitors : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        phone_calls : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        phone_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        phone_through_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        relative_ctr : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_absolute_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_budget_lost_absolute_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_budget_lost_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_budget_lost_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_click_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_exact_match_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_rank_lost_absolute_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_rank_lost_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_rank_lost_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        search_top_impression_share : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        speed_score : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_impression_percentage : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        valid_accelerated_mobile_pages_clicks_percentage : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        value_per_all_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        value_per_conversion : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        value_per_current_model_attributed_conversion : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_quartile_100_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_quartile_25_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_quartile_50_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_quartile_75_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_view_rate : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        video_views : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        view_through_conversions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Metrics: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"absolute_top_impression_percentage",u"active_view_cpm",u"active_view_ctr",u"active_view_impressions",u"active_view_measurability",u"active_view_measurable_cost_micros",u"active_view_measurable_impressions",u"active_view_viewability",u"all_conversions",u"all_conversions_from_click_to_call",u"all_conversions_from_directions",u"all_conversions_from_interactions_rate",u"all_conversions_from_interactions_value_per_interaction",u"all_conversions_from_menu",u"all_conversions_from_order",u"all_conversions_from_other_engagement",u"all_conversions_from_store_visit",u"all_conversions_from_store_website",u"all_conversions_value",u"all_conversions_value_per_cost",u"average_cost",u"average_cpc",u"average_cpe",u"average_cpm",u"average_cpv",u"average_frequency",u"average_page_views",u"average_position",u"average_time_on_site",u"benchmark_average_max_cpc",u"benchmark_ctr",u"bounce_rate",u"clicks",u"combined_clicks",u"combined_clicks_per_query",u"combined_queries",u"content_budget_lost_impression_share",u"content_impression_share",u"content_rank_lost_impression_share",u"conversion_last_conversion_date",u"conversion_last_received_request_date_time",u"conversions",u"conversions_from_interactions_rate",u"conversions_from_interactions_value_per_interaction",u"conversions_value",u"conversions_value_per_cost",u"cost_micros",u"cost_per_all_conversions",u"cost_per_conversion",u"cost_per_current_model_attributed_conversion",u"cross_device_conversions",u"ctr",u"current_model_attributed_conversions",u"current_model_attributed_conversions_from_interactions_rate",u"current_model_attributed_conversions_from_interactions_value_per_interaction",u"current_model_attributed_conversions_value",u"current_model_attributed_conversions_value_per_cost",u"engagement_rate",u"engagements",u"gmail_forwards",u"gmail_saves",u"gmail_secondary_clicks",u"historical_quality_score",u"hotel_average_lead_value_micros",u"impression_reach",u"impressions",u"impressions_from_store_reach",u"interaction_rate",u"interactions",u"invalid_click_rate",u"invalid_clicks",u"mobile_friendly_clicks_percentage",u"organic_clicks",u"organic_clicks_per_query",u"organic_impressions",u"organic_impressions_per_query",u"organic_queries",u"percent_new_visitors",u"phone_calls",u"phone_impressions",u"phone_through_rate",u"relative_ctr",u"search_absolute_top_impression_share",u"search_budget_lost_absolute_top_impression_share",u"search_budget_lost_impression_share",u"search_budget_lost_top_impression_share",u"search_click_share",u"search_exact_match_impression_share",u"search_impression_share",u"search_rank_lost_absolute_top_impression_share",u"search_rank_lost_impression_share",u"search_rank_lost_top_impression_share",u"search_top_impression_share",u"speed_score",u"top_impression_percentage",u"valid_accelerated_mobile_pages_clicks_percentage",u"value_per_all_conversions",u"value_per_conversion",u"value_per_current_model_attributed_conversion",u"video_quartile_100_rate",u"video_quartile_25_rate",u"video_quartile_50_rate",u"video_quartile_75_rate",u"video_view_rate",u"video_views",u"view_through_conversions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"absolute_top_impression_percentage",u"active_view_cpm",u"active_view_ctr",u"active_view_impressions",u"active_view_measurability",u"active_view_measurable_cost_micros",u"active_view_measurable_impressions",u"active_view_viewability",u"all_conversions",u"all_conversions_from_click_to_call",u"all_conversions_from_directions",u"all_conversions_from_interactions_rate",u"all_conversions_from_interactions_value_per_interaction",u"all_conversions_from_menu",u"all_conversions_from_order",u"all_conversions_from_other_engagement",u"all_conversions_from_store_visit",u"all_conversions_from_store_website",u"all_conversions_value",u"all_conversions_value_per_cost",u"average_cost",u"average_cpc",u"average_cpe",u"average_cpm",u"average_cpv",u"average_frequency",u"average_page_views",u"average_position",u"average_time_on_site",u"benchmark_average_max_cpc",u"benchmark_ctr",u"bounce_rate",u"clicks",u"combined_clicks",u"combined_clicks_per_query",u"combined_queries",u"content_budget_lost_impression_share",u"content_impression_share",u"content_rank_lost_impression_share",u"conversion_last_conversion_date",u"conversion_last_received_request_date_time",u"conversions",u"conversions_from_interactions_rate",u"conversions_from_interactions_value_per_interaction",u"conversions_value",u"conversions_value_per_cost",u"cost_micros",u"cost_per_all_conversions",u"cost_per_conversion",u"cost_per_current_model_attributed_conversion",u"cross_device_conversions",u"ctr",u"current_model_attributed_conversions",u"current_model_attributed_conversions_from_interactions_rate",u"current_model_attributed_conversions_from_interactions_value_per_interaction",u"current_model_attributed_conversions_value",u"current_model_attributed_conversions_value_per_cost",u"engagement_rate",u"engagements",u"gmail_forwards",u"gmail_saves",u"gmail_secondary_clicks",u"historical_creative_quality_score",u"historical_landing_page_quality_score",u"historical_quality_score",u"historical_search_predicted_ctr",u"hotel_average_lead_value_micros",u"impression_reach",u"impressions",u"impressions_from_store_reach",u"interaction_event_types",u"interaction_rate",u"interactions",u"invalid_click_rate",u"invalid_clicks",u"mobile_friendly_clicks_percentage",u"organic_clicks",u"organic_clicks_per_query",u"organic_impressions",u"organic_impressions_per_query",u"organic_queries",u"percent_new_visitors",u"phone_calls",u"phone_impressions",u"phone_through_rate",u"relative_ctr",u"search_absolute_top_impression_share",u"search_budget_lost_absolute_top_impression_share",u"search_budget_lost_impression_share",u"search_budget_lost_top_impression_share",u"search_click_share",u"search_exact_match_impression_share",u"search_impression_share",u"search_rank_lost_absolute_top_impression_share",u"search_rank_lost_impression_share",u"search_rank_lost_top_impression_share",u"search_top_impression_share",u"speed_score",u"top_impression_percentage",u"valid_accelerated_mobile_pages_clicks_percentage",u"value_per_all_conversions",u"value_per_conversion",u"value_per_current_model_attributed_conversion",u"video_quartile_100_rate",u"video_quartile_25_rate",u"video_quartile_50_rate",u"video_quartile_75_rate",u"video_view_rate",u"video_views",u"view_through_conversions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"absolute_top_impression_percentage",b"absolute_top_impression_percentage",u"active_view_cpm",b"active_view_cpm",u"active_view_ctr",b"active_view_ctr",u"active_view_impressions",b"active_view_impressions",u"active_view_measurability",b"active_view_measurability",u"active_view_measurable_cost_micros",b"active_view_measurable_cost_micros",u"active_view_measurable_impressions",b"active_view_measurable_impressions",u"active_view_viewability",b"active_view_viewability",u"all_conversions",b"all_conversions",u"all_conversions_from_click_to_call",b"all_conversions_from_click_to_call",u"all_conversions_from_directions",b"all_conversions_from_directions",u"all_conversions_from_interactions_rate",b"all_conversions_from_interactions_rate",u"all_conversions_from_interactions_value_per_interaction",b"all_conversions_from_interactions_value_per_interaction",u"all_conversions_from_menu",b"all_conversions_from_menu",u"all_conversions_from_order",b"all_conversions_from_order",u"all_conversions_from_other_engagement",b"all_conversions_from_other_engagement",u"all_conversions_from_store_visit",b"all_conversions_from_store_visit",u"all_conversions_from_store_website",b"all_conversions_from_store_website",u"all_conversions_value",b"all_conversions_value",u"all_conversions_value_per_cost",b"all_conversions_value_per_cost",u"average_cost",b"average_cost",u"average_cpc",b"average_cpc",u"average_cpe",b"average_cpe",u"average_cpm",b"average_cpm",u"average_cpv",b"average_cpv",u"average_frequency",b"average_frequency",u"average_page_views",b"average_page_views",u"average_position",b"average_position",u"average_time_on_site",b"average_time_on_site",u"benchmark_average_max_cpc",b"benchmark_average_max_cpc",u"benchmark_ctr",b"benchmark_ctr",u"bounce_rate",b"bounce_rate",u"clicks",b"clicks",u"combined_clicks",b"combined_clicks",u"combined_clicks_per_query",b"combined_clicks_per_query",u"combined_queries",b"combined_queries",u"content_budget_lost_impression_share",b"content_budget_lost_impression_share",u"content_impression_share",b"content_impression_share",u"content_rank_lost_impression_share",b"content_rank_lost_impression_share",u"conversion_last_conversion_date",b"conversion_last_conversion_date",u"conversion_last_received_request_date_time",b"conversion_last_received_request_date_time",u"conversions",b"conversions",u"conversions_from_interactions_rate",b"conversions_from_interactions_rate",u"conversions_from_interactions_value_per_interaction",b"conversions_from_interactions_value_per_interaction",u"conversions_value",b"conversions_value",u"conversions_value_per_cost",b"conversions_value_per_cost",u"cost_micros",b"cost_micros",u"cost_per_all_conversions",b"cost_per_all_conversions",u"cost_per_conversion",b"cost_per_conversion",u"cost_per_current_model_attributed_conversion",b"cost_per_current_model_attributed_conversion",u"cross_device_conversions",b"cross_device_conversions",u"ctr",b"ctr",u"current_model_attributed_conversions",b"current_model_attributed_conversions",u"current_model_attributed_conversions_from_interactions_rate",b"current_model_attributed_conversions_from_interactions_rate",u"current_model_attributed_conversions_from_interactions_value_per_interaction",b"current_model_attributed_conversions_from_interactions_value_per_interaction",u"current_model_attributed_conversions_value",b"current_model_attributed_conversions_value",u"current_model_attributed_conversions_value_per_cost",b"current_model_attributed_conversions_value_per_cost",u"engagement_rate",b"engagement_rate",u"engagements",b"engagements",u"gmail_forwards",b"gmail_forwards",u"gmail_saves",b"gmail_saves",u"gmail_secondary_clicks",b"gmail_secondary_clicks",u"historical_quality_score",b"historical_quality_score",u"hotel_average_lead_value_micros",b"hotel_average_lead_value_micros",u"impression_reach",b"impression_reach",u"impressions",b"impressions",u"impressions_from_store_reach",b"impressions_from_store_reach",u"interaction_rate",b"interaction_rate",u"interactions",b"interactions",u"invalid_click_rate",b"invalid_click_rate",u"invalid_clicks",b"invalid_clicks",u"mobile_friendly_clicks_percentage",b"mobile_friendly_clicks_percentage",u"organic_clicks",b"organic_clicks",u"organic_clicks_per_query",b"organic_clicks_per_query",u"organic_impressions",b"organic_impressions",u"organic_impressions_per_query",b"organic_impressions_per_query",u"organic_queries",b"organic_queries",u"percent_new_visitors",b"percent_new_visitors",u"phone_calls",b"phone_calls",u"phone_impressions",b"phone_impressions",u"phone_through_rate",b"phone_through_rate",u"relative_ctr",b"relative_ctr",u"search_absolute_top_impression_share",b"search_absolute_top_impression_share",u"search_budget_lost_absolute_top_impression_share",b"search_budget_lost_absolute_top_impression_share",u"search_budget_lost_impression_share",b"search_budget_lost_impression_share",u"search_budget_lost_top_impression_share",b"search_budget_lost_top_impression_share",u"search_click_share",b"search_click_share",u"search_exact_match_impression_share",b"search_exact_match_impression_share",u"search_impression_share",b"search_impression_share",u"search_rank_lost_absolute_top_impression_share",b"search_rank_lost_absolute_top_impression_share",u"search_rank_lost_impression_share",b"search_rank_lost_impression_share",u"search_rank_lost_top_impression_share",b"search_rank_lost_top_impression_share",u"search_top_impression_share",b"search_top_impression_share",u"speed_score",b"speed_score",u"top_impression_percentage",b"top_impression_percentage",u"valid_accelerated_mobile_pages_clicks_percentage",b"valid_accelerated_mobile_pages_clicks_percentage",u"value_per_all_conversions",b"value_per_all_conversions",u"value_per_conversion",b"value_per_conversion",u"value_per_current_model_attributed_conversion",b"value_per_current_model_attributed_conversion",u"video_quartile_100_rate",b"video_quartile_100_rate",u"video_quartile_25_rate",b"video_quartile_25_rate",u"video_quartile_50_rate",b"video_quartile_50_rate",u"video_quartile_75_rate",b"video_quartile_75_rate",u"video_view_rate",b"video_view_rate",u"video_views",b"video_views",u"view_through_conversions",b"view_through_conversions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"absolute_top_impression_percentage",b"absolute_top_impression_percentage",u"active_view_cpm",b"active_view_cpm",u"active_view_ctr",b"active_view_ctr",u"active_view_impressions",b"active_view_impressions",u"active_view_measurability",b"active_view_measurability",u"active_view_measurable_cost_micros",b"active_view_measurable_cost_micros",u"active_view_measurable_impressions",b"active_view_measurable_impressions",u"active_view_viewability",b"active_view_viewability",u"all_conversions",b"all_conversions",u"all_conversions_from_click_to_call",b"all_conversions_from_click_to_call",u"all_conversions_from_directions",b"all_conversions_from_directions",u"all_conversions_from_interactions_rate",b"all_conversions_from_interactions_rate",u"all_conversions_from_interactions_value_per_interaction",b"all_conversions_from_interactions_value_per_interaction",u"all_conversions_from_menu",b"all_conversions_from_menu",u"all_conversions_from_order",b"all_conversions_from_order",u"all_conversions_from_other_engagement",b"all_conversions_from_other_engagement",u"all_conversions_from_store_visit",b"all_conversions_from_store_visit",u"all_conversions_from_store_website",b"all_conversions_from_store_website",u"all_conversions_value",b"all_conversions_value",u"all_conversions_value_per_cost",b"all_conversions_value_per_cost",u"average_cost",b"average_cost",u"average_cpc",b"average_cpc",u"average_cpe",b"average_cpe",u"average_cpm",b"average_cpm",u"average_cpv",b"average_cpv",u"average_frequency",b"average_frequency",u"average_page_views",b"average_page_views",u"average_position",b"average_position",u"average_time_on_site",b"average_time_on_site",u"benchmark_average_max_cpc",b"benchmark_average_max_cpc",u"benchmark_ctr",b"benchmark_ctr",u"bounce_rate",b"bounce_rate",u"clicks",b"clicks",u"combined_clicks",b"combined_clicks",u"combined_clicks_per_query",b"combined_clicks_per_query",u"combined_queries",b"combined_queries",u"content_budget_lost_impression_share",b"content_budget_lost_impression_share",u"content_impression_share",b"content_impression_share",u"content_rank_lost_impression_share",b"content_rank_lost_impression_share",u"conversion_last_conversion_date",b"conversion_last_conversion_date",u"conversion_last_received_request_date_time",b"conversion_last_received_request_date_time",u"conversions",b"conversions",u"conversions_from_interactions_rate",b"conversions_from_interactions_rate",u"conversions_from_interactions_value_per_interaction",b"conversions_from_interactions_value_per_interaction",u"conversions_value",b"conversions_value",u"conversions_value_per_cost",b"conversions_value_per_cost",u"cost_micros",b"cost_micros",u"cost_per_all_conversions",b"cost_per_all_conversions",u"cost_per_conversion",b"cost_per_conversion",u"cost_per_current_model_attributed_conversion",b"cost_per_current_model_attributed_conversion",u"cross_device_conversions",b"cross_device_conversions",u"ctr",b"ctr",u"current_model_attributed_conversions",b"current_model_attributed_conversions",u"current_model_attributed_conversions_from_interactions_rate",b"current_model_attributed_conversions_from_interactions_rate",u"current_model_attributed_conversions_from_interactions_value_per_interaction",b"current_model_attributed_conversions_from_interactions_value_per_interaction",u"current_model_attributed_conversions_value",b"current_model_attributed_conversions_value",u"current_model_attributed_conversions_value_per_cost",b"current_model_attributed_conversions_value_per_cost",u"engagement_rate",b"engagement_rate",u"engagements",b"engagements",u"gmail_forwards",b"gmail_forwards",u"gmail_saves",b"gmail_saves",u"gmail_secondary_clicks",b"gmail_secondary_clicks",u"historical_creative_quality_score",b"historical_creative_quality_score",u"historical_landing_page_quality_score",b"historical_landing_page_quality_score",u"historical_quality_score",b"historical_quality_score",u"historical_search_predicted_ctr",b"historical_search_predicted_ctr",u"hotel_average_lead_value_micros",b"hotel_average_lead_value_micros",u"impression_reach",b"impression_reach",u"impressions",b"impressions",u"impressions_from_store_reach",b"impressions_from_store_reach",u"interaction_event_types",b"interaction_event_types",u"interaction_rate",b"interaction_rate",u"interactions",b"interactions",u"invalid_click_rate",b"invalid_click_rate",u"invalid_clicks",b"invalid_clicks",u"mobile_friendly_clicks_percentage",b"mobile_friendly_clicks_percentage",u"organic_clicks",b"organic_clicks",u"organic_clicks_per_query",b"organic_clicks_per_query",u"organic_impressions",b"organic_impressions",u"organic_impressions_per_query",b"organic_impressions_per_query",u"organic_queries",b"organic_queries",u"percent_new_visitors",b"percent_new_visitors",u"phone_calls",b"phone_calls",u"phone_impressions",b"phone_impressions",u"phone_through_rate",b"phone_through_rate",u"relative_ctr",b"relative_ctr",u"search_absolute_top_impression_share",b"search_absolute_top_impression_share",u"search_budget_lost_absolute_top_impression_share",b"search_budget_lost_absolute_top_impression_share",u"search_budget_lost_impression_share",b"search_budget_lost_impression_share",u"search_budget_lost_top_impression_share",b"search_budget_lost_top_impression_share",u"search_click_share",b"search_click_share",u"search_exact_match_impression_share",b"search_exact_match_impression_share",u"search_impression_share",b"search_impression_share",u"search_rank_lost_absolute_top_impression_share",b"search_rank_lost_absolute_top_impression_share",u"search_rank_lost_impression_share",b"search_rank_lost_impression_share",u"search_rank_lost_top_impression_share",b"search_rank_lost_top_impression_share",u"search_top_impression_share",b"search_top_impression_share",u"speed_score",b"speed_score",u"top_impression_percentage",b"top_impression_percentage",u"valid_accelerated_mobile_pages_clicks_percentage",b"valid_accelerated_mobile_pages_clicks_percentage",u"value_per_all_conversions",b"value_per_all_conversions",u"value_per_conversion",b"value_per_conversion",u"value_per_current_model_attributed_conversion",b"value_per_current_model_attributed_conversion",u"video_quartile_100_rate",b"video_quartile_100_rate",u"video_quartile_25_rate",b"video_quartile_25_rate",u"video_quartile_50_rate",b"video_quartile_50_rate",u"video_quartile_75_rate",b"video_quartile_75_rate",u"video_view_rate",b"video_view_rate",u"video_views",b"video_views",u"view_through_conversions",b"view_through_conversions"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.user_lists_pb2 import (
    BasicUserListInfo as google___ads___googleads___v2___common___user_lists_pb2___BasicUserListInfo,
    CrmBasedUserListInfo as google___ads___googleads___v2___common___user_lists_pb2___CrmBasedUserListInfo,
    LogicalUserListInfo as google___ads___googleads___v2___common___user_lists_pb2___LogicalUserListInfo,
    RuleBasedUserListInfo as google___ads___googleads___v2___common___user_lists_pb2___RuleBasedUserListInfo,
    SimilarUserListInfo as google___ads___googleads___v2___common___user_lists_pb2___SimilarUserListInfo,
)

from google.ads.google_ads.v2.proto.enums.access_reason_pb2 import (
    AccessReasonEnum as google___ads___googleads___v2___enums___access_reason_pb2___AccessReasonEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_access_status_pb2 import (
    UserListAccessStatusEnum as google___ads___googleads___v2___enums___user_list_access_status_pb2___UserListAccessStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_closing_reason_pb2 import (
    UserListClosingReasonEnum as google___ads___googleads___v2___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_membership_status_pb2 import (
    UserListMembershipStatusEnum as google___ads___googleads___v2___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_size_range_pb2 import (
    UserListSizeRangeEnum as google___ads___googleads___v2___enums___user_list_size_range_pb2___UserListSizeRangeEnum,
)

from google.ads.google_ads.v2.proto.enums.user_list_type_pb2 import (
    UserListTypeEnum as google___ads___googleads___v2___enums___user_list_type_pb2___UserListTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class UserList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    membership_status = ... # type: google___ads___googleads___v2___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum.UserListMembershipStatus
    size_range_for_display = ... # type: google___ads___googleads___v2___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRange
    size_range_for_search = ... # type: google___ads___googleads___v2___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRange
    type = ... # type: google___ads___googleads___v2___enums___user_list_type_pb2___UserListTypeEnum.UserListType
    closing_reason = ... # type: google___ads___googleads___v2___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum.UserListClosingReason
    access_reason = ... # type: google___ads___googleads___v2___enums___access_reason_pb2___AccessReasonEnum.AccessReason
    account_user_list_status = ... # type: google___ads___googleads___v2___enums___user_list_access_status_pb2___UserListAccessStatusEnum.UserListAccessStatus

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def read_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def integration_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def membership_life_span(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def size_for_display(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def size_for_search(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def eligible_for_search(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def eligible_for_display(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def crm_based_user_list(self) -> google___ads___googleads___v2___common___user_lists_pb2___CrmBasedUserListInfo: ...

    @property
    def similar_user_list(self) -> google___ads___googleads___v2___common___user_lists_pb2___SimilarUserListInfo: ...

    @property
    def rule_based_user_list(self) -> google___ads___googleads___v2___common___user_lists_pb2___RuleBasedUserListInfo: ...

    @property
    def logical_user_list(self) -> google___ads___googleads___v2___common___user_lists_pb2___LogicalUserListInfo: ...

    @property
    def basic_user_list(self) -> google___ads___googleads___v2___common___user_lists_pb2___BasicUserListInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        read_only : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        description : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        membership_status : typing___Optional[google___ads___googleads___v2___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum.UserListMembershipStatus] = None,
        integration_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        membership_life_span : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        size_for_display : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        size_range_for_display : typing___Optional[google___ads___googleads___v2___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRange] = None,
        size_for_search : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        size_range_for_search : typing___Optional[google___ads___googleads___v2___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRange] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___user_list_type_pb2___UserListTypeEnum.UserListType] = None,
        closing_reason : typing___Optional[google___ads___googleads___v2___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum.UserListClosingReason] = None,
        access_reason : typing___Optional[google___ads___googleads___v2___enums___access_reason_pb2___AccessReasonEnum.AccessReason] = None,
        account_user_list_status : typing___Optional[google___ads___googleads___v2___enums___user_list_access_status_pb2___UserListAccessStatusEnum.UserListAccessStatus] = None,
        eligible_for_search : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        eligible_for_display : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        crm_based_user_list : typing___Optional[google___ads___googleads___v2___common___user_lists_pb2___CrmBasedUserListInfo] = None,
        similar_user_list : typing___Optional[google___ads___googleads___v2___common___user_lists_pb2___SimilarUserListInfo] = None,
        rule_based_user_list : typing___Optional[google___ads___googleads___v2___common___user_lists_pb2___RuleBasedUserListInfo] = None,
        logical_user_list : typing___Optional[google___ads___googleads___v2___common___user_lists_pb2___LogicalUserListInfo] = None,
        basic_user_list : typing___Optional[google___ads___googleads___v2___common___user_lists_pb2___BasicUserListInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"basic_user_list",u"crm_based_user_list",u"description",u"eligible_for_display",u"eligible_for_search",u"id",u"integration_code",u"logical_user_list",u"membership_life_span",u"name",u"read_only",u"rule_based_user_list",u"similar_user_list",u"size_for_display",u"size_for_search",u"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"access_reason",u"account_user_list_status",u"basic_user_list",u"closing_reason",u"crm_based_user_list",u"description",u"eligible_for_display",u"eligible_for_search",u"id",u"integration_code",u"logical_user_list",u"membership_life_span",u"membership_status",u"name",u"read_only",u"resource_name",u"rule_based_user_list",u"similar_user_list",u"size_for_display",u"size_for_search",u"size_range_for_display",u"size_range_for_search",u"type",u"user_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"basic_user_list",b"basic_user_list",u"crm_based_user_list",b"crm_based_user_list",u"description",b"description",u"eligible_for_display",b"eligible_for_display",u"eligible_for_search",b"eligible_for_search",u"id",b"id",u"integration_code",b"integration_code",u"logical_user_list",b"logical_user_list",u"membership_life_span",b"membership_life_span",u"name",b"name",u"read_only",b"read_only",u"rule_based_user_list",b"rule_based_user_list",u"similar_user_list",b"similar_user_list",u"size_for_display",b"size_for_display",u"size_for_search",b"size_for_search",u"user_list",b"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"access_reason",b"access_reason",u"account_user_list_status",b"account_user_list_status",u"basic_user_list",b"basic_user_list",u"closing_reason",b"closing_reason",u"crm_based_user_list",b"crm_based_user_list",u"description",b"description",u"eligible_for_display",b"eligible_for_display",u"eligible_for_search",b"eligible_for_search",u"id",b"id",u"integration_code",b"integration_code",u"logical_user_list",b"logical_user_list",u"membership_life_span",b"membership_life_span",u"membership_status",b"membership_status",u"name",b"name",u"read_only",b"read_only",u"resource_name",b"resource_name",u"rule_based_user_list",b"rule_based_user_list",u"similar_user_list",b"similar_user_list",u"size_for_display",b"size_for_display",u"size_for_search",b"size_for_search",u"size_range_for_display",b"size_range_for_display",u"size_range_for_search",b"size_range_for_search",u"type",b"type",u"user_list",b"user_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"user_list",b"user_list"]) -> typing_extensions___Literal["crm_based_user_list","similar_user_list","rule_based_user_list","logical_user_list","basic_user_list"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AccountBudgetProposalErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AccountBudgetProposalError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AccountBudgetProposalErrorEnum.AccountBudgetProposalError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AccountBudgetProposalErrorEnum.AccountBudgetProposalError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AccountBudgetProposalErrorEnum.AccountBudgetProposalError]]: ...
        UNSPECIFIED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 0)
        UNKNOWN = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 1)
        FIELD_MASK_NOT_ALLOWED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 2)
        IMMUTABLE_FIELD = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 3)
        REQUIRED_FIELD_MISSING = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 4)
        CANNOT_CANCEL_APPROVED_PROPOSAL = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 5)
        CANNOT_REMOVE_UNAPPROVED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 6)
        CANNOT_REMOVE_RUNNING_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 7)
        CANNOT_END_UNAPPROVED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 8)
        CANNOT_END_INACTIVE_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 9)
        BUDGET_NAME_REQUIRED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 10)
        CANNOT_UPDATE_OLD_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 11)
        CANNOT_END_IN_PAST = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 12)
        CANNOT_EXTEND_END_TIME = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 13)
        PURCHASE_ORDER_NUMBER_REQUIRED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 14)
        PENDING_UPDATE_PROPOSAL_EXISTS = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 15)
        MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 16)
        CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 17)
        SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 18)
        UPDATE_IS_NO_OP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 19)
        END_TIME_MUST_FOLLOW_START_TIME = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 20)
        BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 21)
        NOT_AUTHORIZED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 22)
        INVALID_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 23)
    UNSPECIFIED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 0)
    UNKNOWN = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 1)
    FIELD_MASK_NOT_ALLOWED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 2)
    IMMUTABLE_FIELD = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 3)
    REQUIRED_FIELD_MISSING = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 4)
    CANNOT_CANCEL_APPROVED_PROPOSAL = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 5)
    CANNOT_REMOVE_UNAPPROVED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 6)
    CANNOT_REMOVE_RUNNING_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 7)
    CANNOT_END_UNAPPROVED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 8)
    CANNOT_END_INACTIVE_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 9)
    BUDGET_NAME_REQUIRED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 10)
    CANNOT_UPDATE_OLD_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 11)
    CANNOT_END_IN_PAST = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 12)
    CANNOT_EXTEND_END_TIME = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 13)
    PURCHASE_ORDER_NUMBER_REQUIRED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 14)
    PENDING_UPDATE_PROPOSAL_EXISTS = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 15)
    MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 16)
    CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 17)
    SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 18)
    UPDATE_IS_NO_OP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 19)
    END_TIME_MUST_FOLLOW_START_TIME = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 20)
    BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 21)
    NOT_AUTHORIZED = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 22)
    INVALID_BILLING_SETUP = typing___cast(AccountBudgetProposalErrorEnum.AccountBudgetProposalError, 23)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AccountBudgetProposalErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.targeting_dimension_pb2 import (
    TargetingDimensionEnum as google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class TargetingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_restrictions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[TargetRestriction]: ...

    def __init__(self,
        *,
        target_restrictions : typing___Optional[typing___Iterable[TargetRestriction]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetingSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"target_restrictions"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"target_restrictions",b"target_restrictions"]) -> None: ...

class TargetRestriction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    targeting_dimension = ... # type: google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension

    @property
    def bid_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        targeting_dimension : typing___Optional[google___ads___googleads___v1___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimension] = None,
        bid_only : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetRestriction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_only",u"targeting_dimension"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_only",b"bid_only"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_only",b"bid_only",u"targeting_dimension",b"targeting_dimension"]) -> None: ...



import logging

import grpc  # type: ignore

from .interceptor_mixin import InterceptorMixin
from grpc import UnaryUnaryClientInterceptor
from typing import Optional, Callable, TypeVar

_Request = TypeVar("_Request")
_Response = TypeVar("_Response")


class LoggingInterceptor(InterceptorMixin, UnaryUnaryClientInterceptor):
    endpoint: str = ...
    logger: logging.Logger = ...
    def __init__(self, logger: logging.Logger, endpoint: Optional[str] = ...) -> None: ...
    def intercept_unary_unary(self, continuation: Callable[[grpc.ClientCallDetails, _Request], _Response], client_call_details: grpc.ClientCallDetails, request: _Request) -> _Response: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import (
    AppAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___AppAdInfo,
    AppEngagementAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___AppEngagementAdInfo,
    CallOnlyAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___CallOnlyAdInfo,
    DisplayUploadAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedTextAdInfo,
    GmailAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___GmailAdInfo,
    HotelAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___HotelAdInfo,
    ImageAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ImageAdInfo,
    LegacyAppInstallAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo,
    ResponsiveDisplayAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingProductAdInfo,
    ShoppingSmartAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingSmartAdInfo,
    TextAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___TextAdInfo,
    VideoAdInfo as google___ads___googleads___v1___common___ad_type_infos_pb2___VideoAdInfo,
)

from google.ads.google_ads.v1.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v1.proto.common.final_app_url_pb2 import (
    FinalAppUrl as google___ads___googleads___v1___common___final_app_url_pb2___FinalAppUrl,
)

from google.ads.google_ads.v1.proto.common.url_collection_pb2 import (
    UrlCollection as google___ads___googleads___v1___common___url_collection_pb2___UrlCollection,
)

from google.ads.google_ads.v1.proto.enums.ad_type_pb2 import (
    AdTypeEnum as google___ads___googleads___v1___enums___ad_type_pb2___AdTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v1___enums___device_pb2___DeviceEnum,
)

from google.ads.google_ads.v1.proto.enums.system_managed_entity_source_pb2 import (
    SystemManagedResourceSourceEnum as google___ads___googleads___v1___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Ad(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v1___enums___ad_type_pb2___AdTypeEnum.AdType
    device_preference = ... # type: google___ads___googleads___v1___enums___device_pb2___DeviceEnum.Device
    system_managed_resource_source = ... # type: google___ads___googleads___v1___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSource

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_app_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___final_app_url_pb2___FinalAppUrl]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def display_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def added_by_google_ads(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def url_collections(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___url_collection_pb2___UrlCollection]: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def text_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___TextAdInfo: ...

    @property
    def expanded_text_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedTextAdInfo: ...

    @property
    def call_only_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___CallOnlyAdInfo: ...

    @property
    def expanded_dynamic_search_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo: ...

    @property
    def hotel_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___HotelAdInfo: ...

    @property
    def shopping_smart_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingSmartAdInfo: ...

    @property
    def shopping_product_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingProductAdInfo: ...

    @property
    def gmail_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___GmailAdInfo: ...

    @property
    def image_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ImageAdInfo: ...

    @property
    def video_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___VideoAdInfo: ...

    @property
    def responsive_search_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveSearchAdInfo: ...

    @property
    def legacy_responsive_display_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo: ...

    @property
    def app_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___AppAdInfo: ...

    @property
    def legacy_app_install_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyAppInstallAdInfo: ...

    @property
    def responsive_display_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo: ...

    @property
    def display_upload_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___DisplayUploadAdInfo: ...

    @property
    def app_engagement_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___AppEngagementAdInfo: ...

    @property
    def shopping_comparison_listing_ad(self) -> google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo: ...

    def __init__(self,
        *,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_app_urls : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___final_app_url_pb2___FinalAppUrl]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]] = None,
        display_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___ad_type_pb2___AdTypeEnum.AdType] = None,
        added_by_google_ads : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        device_preference : typing___Optional[google___ads___googleads___v1___enums___device_pb2___DeviceEnum.Device] = None,
        url_collections : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___url_collection_pb2___UrlCollection]] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        system_managed_resource_source : typing___Optional[google___ads___googleads___v1___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSource] = None,
        text_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___TextAdInfo] = None,
        expanded_text_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedTextAdInfo] = None,
        call_only_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___CallOnlyAdInfo] = None,
        expanded_dynamic_search_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo] = None,
        hotel_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___HotelAdInfo] = None,
        shopping_smart_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingSmartAdInfo] = None,
        shopping_product_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingProductAdInfo] = None,
        gmail_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___GmailAdInfo] = None,
        image_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ImageAdInfo] = None,
        video_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___VideoAdInfo] = None,
        responsive_search_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveSearchAdInfo] = None,
        legacy_responsive_display_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo] = None,
        app_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___AppAdInfo] = None,
        legacy_app_install_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___LegacyAppInstallAdInfo] = None,
        responsive_display_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo] = None,
        display_upload_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___DisplayUploadAdInfo] = None,
        app_engagement_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___AppEngagementAdInfo] = None,
        shopping_comparison_listing_ad : typing___Optional[google___ads___googleads___v1___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Ad: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_data",u"added_by_google_ads",u"app_ad",u"app_engagement_ad",u"call_only_ad",u"display_upload_ad",u"display_url",u"expanded_dynamic_search_ad",u"expanded_text_ad",u"gmail_ad",u"hotel_ad",u"id",u"image_ad",u"legacy_app_install_ad",u"legacy_responsive_display_ad",u"name",u"responsive_display_ad",u"responsive_search_ad",u"shopping_comparison_listing_ad",u"shopping_product_ad",u"shopping_smart_ad",u"text_ad",u"tracking_url_template",u"video_ad"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_data",u"added_by_google_ads",u"app_ad",u"app_engagement_ad",u"call_only_ad",u"device_preference",u"display_upload_ad",u"display_url",u"expanded_dynamic_search_ad",u"expanded_text_ad",u"final_app_urls",u"final_mobile_urls",u"final_urls",u"gmail_ad",u"hotel_ad",u"id",u"image_ad",u"legacy_app_install_ad",u"legacy_responsive_display_ad",u"name",u"responsive_display_ad",u"responsive_search_ad",u"shopping_comparison_listing_ad",u"shopping_product_ad",u"shopping_smart_ad",u"system_managed_resource_source",u"text_ad",u"tracking_url_template",u"type",u"url_collections",u"url_custom_parameters",u"video_ad"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_data",b"ad_data",u"added_by_google_ads",b"added_by_google_ads",u"app_ad",b"app_ad",u"app_engagement_ad",b"app_engagement_ad",u"call_only_ad",b"call_only_ad",u"display_upload_ad",b"display_upload_ad",u"display_url",b"display_url",u"expanded_dynamic_search_ad",b"expanded_dynamic_search_ad",u"expanded_text_ad",b"expanded_text_ad",u"gmail_ad",b"gmail_ad",u"hotel_ad",b"hotel_ad",u"id",b"id",u"image_ad",b"image_ad",u"legacy_app_install_ad",b"legacy_app_install_ad",u"legacy_responsive_display_ad",b"legacy_responsive_display_ad",u"name",b"name",u"responsive_display_ad",b"responsive_display_ad",u"responsive_search_ad",b"responsive_search_ad",u"shopping_comparison_listing_ad",b"shopping_comparison_listing_ad",u"shopping_product_ad",b"shopping_product_ad",u"shopping_smart_ad",b"shopping_smart_ad",u"text_ad",b"text_ad",u"tracking_url_template",b"tracking_url_template",u"video_ad",b"video_ad"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_data",b"ad_data",u"added_by_google_ads",b"added_by_google_ads",u"app_ad",b"app_ad",u"app_engagement_ad",b"app_engagement_ad",u"call_only_ad",b"call_only_ad",u"device_preference",b"device_preference",u"display_upload_ad",b"display_upload_ad",u"display_url",b"display_url",u"expanded_dynamic_search_ad",b"expanded_dynamic_search_ad",u"expanded_text_ad",b"expanded_text_ad",u"final_app_urls",b"final_app_urls",u"final_mobile_urls",b"final_mobile_urls",u"final_urls",b"final_urls",u"gmail_ad",b"gmail_ad",u"hotel_ad",b"hotel_ad",u"id",b"id",u"image_ad",b"image_ad",u"legacy_app_install_ad",b"legacy_app_install_ad",u"legacy_responsive_display_ad",b"legacy_responsive_display_ad",u"name",b"name",u"responsive_display_ad",b"responsive_display_ad",u"responsive_search_ad",b"responsive_search_ad",u"shopping_comparison_listing_ad",b"shopping_comparison_listing_ad",u"shopping_product_ad",b"shopping_product_ad",u"shopping_smart_ad",b"shopping_smart_ad",u"system_managed_resource_source",b"system_managed_resource_source",u"text_ad",b"text_ad",u"tracking_url_template",b"tracking_url_template",u"type",b"type",u"url_collections",b"url_collections",u"url_custom_parameters",b"url_custom_parameters",u"video_ad",b"video_ad"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"ad_data",b"ad_data"]) -> typing_extensions___Literal["text_ad","expanded_text_ad","call_only_ad","expanded_dynamic_search_ad","hotel_ad","shopping_smart_ad","shopping_product_ad","gmail_ad","image_ad","video_ad","responsive_search_ad","legacy_responsive_display_ad","app_ad","legacy_app_install_ad","responsive_display_ad","display_upload_ad","app_engagement_ad","shopping_comparison_listing_ad"]: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.conversion_upload_service_grpc_transport import ConversionUploadServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar

from google.ads.google_ads.v2.proto.services.conversion_upload_service_pb2 import ClickConversion, \
    UploadClickConversionsResponse, CallConversion, UploadCallConversionsResponse


class ConversionUploadServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> ConversionUploadServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> ConversionUploadServiceClient: ...
    transport: Union[ConversionUploadServiceGrpcTransport, Callable[[Credentials, type], ConversionUploadServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[ConversionUploadServiceGrpcTransport, Callable[[Credentials, type], ConversionUploadServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def upload_click_conversions(self, customer_id: str, conversions: List[Union[Dict[Any, Any], ClickConversion]], partial_failure: Optional[bool] = ..., validate_only: Optional[bool] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> UploadClickConversionsResponse: ...
    def upload_call_conversions(self, customer_id: str, conversions: List[Union[Dict[Any, Any], CallConversion]], partial_failure: Optional[bool] = ..., validate_only: Optional[bool] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> UploadCallConversionsResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.click_location_pb2 import (
    ClickLocation as google___ads___googleads___v2___common___click_location_pb2___ClickLocation,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ClickView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def area_of_interest(self) -> google___ads___googleads___v2___common___click_location_pb2___ClickLocation: ...

    @property
    def location_of_presence(self) -> google___ads___googleads___v2___common___click_location_pb2___ClickLocation: ...

    @property
    def page_number(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        gclid : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        area_of_interest : typing___Optional[google___ads___googleads___v2___common___click_location_pb2___ClickLocation] = None,
        location_of_presence : typing___Optional[google___ads___googleads___v2___common___click_location_pb2___ClickLocation] = None,
        page_number : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ad_group_ad : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ClickView: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad",u"area_of_interest",u"gclid",u"location_of_presence",u"page_number"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad",u"area_of_interest",u"gclid",u"location_of_presence",u"page_number",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad",b"ad_group_ad",u"area_of_interest",b"area_of_interest",u"gclid",b"gclid",u"location_of_presence",b"location_of_presence",u"page_number",b"page_number"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad",b"ad_group_ad",u"area_of_interest",b"area_of_interest",u"gclid",b"gclid",u"location_of_presence",b"location_of_presence",u"page_number",b"page_number",u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class DistanceBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DistanceBucket(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> DistanceBucketEnum.DistanceBucket: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[DistanceBucketEnum.DistanceBucket]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, DistanceBucketEnum.DistanceBucket]]: ...
        UNSPECIFIED = typing___cast(DistanceBucketEnum.DistanceBucket, 0)
        UNKNOWN = typing___cast(DistanceBucketEnum.DistanceBucket, 1)
        WITHIN_700M = typing___cast(DistanceBucketEnum.DistanceBucket, 2)
        WITHIN_1KM = typing___cast(DistanceBucketEnum.DistanceBucket, 3)
        WITHIN_5KM = typing___cast(DistanceBucketEnum.DistanceBucket, 4)
        WITHIN_10KM = typing___cast(DistanceBucketEnum.DistanceBucket, 5)
        WITHIN_15KM = typing___cast(DistanceBucketEnum.DistanceBucket, 6)
        WITHIN_20KM = typing___cast(DistanceBucketEnum.DistanceBucket, 7)
        WITHIN_25KM = typing___cast(DistanceBucketEnum.DistanceBucket, 8)
        WITHIN_30KM = typing___cast(DistanceBucketEnum.DistanceBucket, 9)
        WITHIN_35KM = typing___cast(DistanceBucketEnum.DistanceBucket, 10)
        WITHIN_40KM = typing___cast(DistanceBucketEnum.DistanceBucket, 11)
        WITHIN_45KM = typing___cast(DistanceBucketEnum.DistanceBucket, 12)
        WITHIN_50KM = typing___cast(DistanceBucketEnum.DistanceBucket, 13)
        WITHIN_55KM = typing___cast(DistanceBucketEnum.DistanceBucket, 14)
        WITHIN_60KM = typing___cast(DistanceBucketEnum.DistanceBucket, 15)
        WITHIN_65KM = typing___cast(DistanceBucketEnum.DistanceBucket, 16)
        BEYOND_65KM = typing___cast(DistanceBucketEnum.DistanceBucket, 17)
        WITHIN_0_7MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 18)
        WITHIN_1MILE = typing___cast(DistanceBucketEnum.DistanceBucket, 19)
        WITHIN_5MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 20)
        WITHIN_10MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 21)
        WITHIN_15MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 22)
        WITHIN_20MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 23)
        WITHIN_25MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 24)
        WITHIN_30MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 25)
        WITHIN_35MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 26)
        WITHIN_40MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 27)
        BEYOND_40MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 28)
    UNSPECIFIED = typing___cast(DistanceBucketEnum.DistanceBucket, 0)
    UNKNOWN = typing___cast(DistanceBucketEnum.DistanceBucket, 1)
    WITHIN_700M = typing___cast(DistanceBucketEnum.DistanceBucket, 2)
    WITHIN_1KM = typing___cast(DistanceBucketEnum.DistanceBucket, 3)
    WITHIN_5KM = typing___cast(DistanceBucketEnum.DistanceBucket, 4)
    WITHIN_10KM = typing___cast(DistanceBucketEnum.DistanceBucket, 5)
    WITHIN_15KM = typing___cast(DistanceBucketEnum.DistanceBucket, 6)
    WITHIN_20KM = typing___cast(DistanceBucketEnum.DistanceBucket, 7)
    WITHIN_25KM = typing___cast(DistanceBucketEnum.DistanceBucket, 8)
    WITHIN_30KM = typing___cast(DistanceBucketEnum.DistanceBucket, 9)
    WITHIN_35KM = typing___cast(DistanceBucketEnum.DistanceBucket, 10)
    WITHIN_40KM = typing___cast(DistanceBucketEnum.DistanceBucket, 11)
    WITHIN_45KM = typing___cast(DistanceBucketEnum.DistanceBucket, 12)
    WITHIN_50KM = typing___cast(DistanceBucketEnum.DistanceBucket, 13)
    WITHIN_55KM = typing___cast(DistanceBucketEnum.DistanceBucket, 14)
    WITHIN_60KM = typing___cast(DistanceBucketEnum.DistanceBucket, 15)
    WITHIN_65KM = typing___cast(DistanceBucketEnum.DistanceBucket, 16)
    BEYOND_65KM = typing___cast(DistanceBucketEnum.DistanceBucket, 17)
    WITHIN_0_7MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 18)
    WITHIN_1MILE = typing___cast(DistanceBucketEnum.DistanceBucket, 19)
    WITHIN_5MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 20)
    WITHIN_10MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 21)
    WITHIN_15MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 22)
    WITHIN_20MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 23)
    WITHIN_25MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 24)
    WITHIN_30MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 25)
    WITHIN_35MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 26)
    WITHIN_40MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 27)
    BEYOND_40MILES = typing___cast(DistanceBucketEnum.DistanceBucket, 28)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DistanceBucketEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.mutate_job_status_pb2 import (
    MutateJobStatusEnum as google___ads___googleads___v1___enums___mutate_job_status_pb2___MutateJobStatusEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class MutateJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MutateJobMetadata(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def creation_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def completion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def estimated_completion_ratio(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        @property
        def operation_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def executed_operation_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            creation_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            completion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            estimated_completion_ratio : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            operation_count : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            executed_operation_count : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> MutateJob.MutateJobMetadata: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"completion_date_time",u"creation_date_time",u"estimated_completion_ratio",u"executed_operation_count",u"operation_count"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"completion_date_time",u"creation_date_time",u"estimated_completion_ratio",u"executed_operation_count",u"operation_count"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"completion_date_time",b"completion_date_time",u"creation_date_time",b"creation_date_time",u"estimated_completion_ratio",b"estimated_completion_ratio",u"executed_operation_count",b"executed_operation_count",u"operation_count",b"operation_count"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"completion_date_time",b"completion_date_time",u"creation_date_time",b"creation_date_time",u"estimated_completion_ratio",b"estimated_completion_ratio",u"executed_operation_count",b"executed_operation_count",u"operation_count",b"operation_count"]) -> None: ...

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v1___enums___mutate_job_status_pb2___MutateJobStatusEnum.MutateJobStatus

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def next_add_sequence_token(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def metadata(self) -> MutateJob.MutateJobMetadata: ...

    @property
    def long_running_operation(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        next_add_sequence_token : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        metadata : typing___Optional[MutateJob.MutateJobMetadata] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___mutate_job_status_pb2___MutateJobStatusEnum.MutateJobStatus] = None,
        long_running_operation : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateJob: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"id",u"long_running_operation",u"metadata",u"next_add_sequence_token"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",u"long_running_operation",u"metadata",u"next_add_sequence_token",u"resource_name",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"id",b"id",u"long_running_operation",b"long_running_operation",u"metadata",b"metadata",u"next_add_sequence_token",b"next_add_sequence_token"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",b"id",u"long_running_operation",b"long_running_operation",u"metadata",b"metadata",u"next_add_sequence_token",b"next_add_sequence_token",u"resource_name",b"resource_name",u"status",b"status"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ChangeStatusResourceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ChangeStatusResourceType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ChangeStatusResourceTypeEnum.ChangeStatusResourceType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ChangeStatusResourceTypeEnum.ChangeStatusResourceType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ChangeStatusResourceTypeEnum.ChangeStatusResourceType]]: ...
        UNSPECIFIED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 0)
        UNKNOWN = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 1)
        AD_GROUP = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 3)
        AD_GROUP_AD = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 4)
        AD_GROUP_CRITERION = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 5)
        CAMPAIGN = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 6)
        CAMPAIGN_CRITERION = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 7)
        FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 9)
        FEED_ITEM = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 10)
        AD_GROUP_FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 11)
        CAMPAIGN_FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 12)
        AD_GROUP_BID_MODIFIER = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 13)
    UNSPECIFIED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 0)
    UNKNOWN = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 1)
    AD_GROUP = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 3)
    AD_GROUP_AD = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 4)
    AD_GROUP_CRITERION = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 5)
    CAMPAIGN = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 6)
    CAMPAIGN_CRITERION = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 7)
    FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 9)
    FEED_ITEM = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 10)
    AD_GROUP_FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 11)
    CAMPAIGN_FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 12)
    AD_GROUP_BID_MODIFIER = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceType, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ChangeStatusResourceTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class SettingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class SettingError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> SettingErrorEnum.SettingError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[SettingErrorEnum.SettingError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, SettingErrorEnum.SettingError]]: ...
        UNSPECIFIED = typing___cast(SettingErrorEnum.SettingError, 0)
        UNKNOWN = typing___cast(SettingErrorEnum.SettingError, 1)
        SETTING_TYPE_IS_NOT_AVAILABLE = typing___cast(SettingErrorEnum.SettingError, 3)
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 4)
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = typing___cast(SettingErrorEnum.SettingError, 5)
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = typing___cast(SettingErrorEnum.SettingError, 6)
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = typing___cast(SettingErrorEnum.SettingError, 7)
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = typing___cast(SettingErrorEnum.SettingError, 8)
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = typing___cast(SettingErrorEnum.SettingError, 9)
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = typing___cast(SettingErrorEnum.SettingError, 10)
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = typing___cast(SettingErrorEnum.SettingError, 11)
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 12)
        UNIVERSAL_APP_CAMPAIGN_SETTING_DUPLICATE_DESCRIPTION = typing___cast(SettingErrorEnum.SettingError, 13)
        UNIVERSAL_APP_CAMPAIGN_SETTING_DESCRIPTION_LINE_WIDTH_TOO_LONG = typing___cast(SettingErrorEnum.SettingError, 14)
        UNIVERSAL_APP_CAMPAIGN_SETTING_APP_ID_CANNOT_BE_MODIFIED = typing___cast(SettingErrorEnum.SettingError, 15)
        TOO_MANY_YOUTUBE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 16)
        TOO_MANY_IMAGE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 17)
        MEDIA_INCOMPATIBLE_FOR_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 18)
        TOO_MANY_EXCLAMATION_MARKS = typing___cast(SettingErrorEnum.SettingError, 19)
    UNSPECIFIED = typing___cast(SettingErrorEnum.SettingError, 0)
    UNKNOWN = typing___cast(SettingErrorEnum.SettingError, 1)
    SETTING_TYPE_IS_NOT_AVAILABLE = typing___cast(SettingErrorEnum.SettingError, 3)
    SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 4)
    TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = typing___cast(SettingErrorEnum.SettingError, 5)
    TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = typing___cast(SettingErrorEnum.SettingError, 6)
    TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = typing___cast(SettingErrorEnum.SettingError, 7)
    DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = typing___cast(SettingErrorEnum.SettingError, 8)
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = typing___cast(SettingErrorEnum.SettingError, 9)
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = typing___cast(SettingErrorEnum.SettingError, 10)
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = typing___cast(SettingErrorEnum.SettingError, 11)
    TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 12)
    UNIVERSAL_APP_CAMPAIGN_SETTING_DUPLICATE_DESCRIPTION = typing___cast(SettingErrorEnum.SettingError, 13)
    UNIVERSAL_APP_CAMPAIGN_SETTING_DESCRIPTION_LINE_WIDTH_TOO_LONG = typing___cast(SettingErrorEnum.SettingError, 14)
    UNIVERSAL_APP_CAMPAIGN_SETTING_APP_ID_CANNOT_BE_MODIFIED = typing___cast(SettingErrorEnum.SettingError, 15)
    TOO_MANY_YOUTUBE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 16)
    TOO_MANY_IMAGE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 17)
    MEDIA_INCOMPATIBLE_FOR_UNIVERSAL_APP_CAMPAIGN = typing___cast(SettingErrorEnum.SettingError, 18)
    TOO_MANY_EXCLAMATION_MARKS = typing___cast(SettingErrorEnum.SettingError, 19)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SettingErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# Stubs for google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class CustomerClientLinkServiceStub:
    GetCustomerClientLink: Any = ...
    MutateCustomerClientLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientLinkServiceServicer:
    def GetCustomerClientLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerClientLink(self, request: Any, context: Any) -> None: ...

def add_CustomerClientLinkServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
